==> atoti_client-0.9.1-py3-none-any.whl: atoti/agg/quantile.py <==
from __future__ import annotations

from typing import overload

from .._doc import doc
from .._docs_utils import QUANTILE_DOC as _QUANTILE_DOC
from .._measure_convertible import VariableMeasureConvertible
from .._measure_description import MeasureDescription
from ..array import quantile as array_quantile
from ..array.quantile import _Q, _Interpolation, _Mode
from ..scope._scope import Scope
from ._utils import (
    QUANTILE_STD_AND_VAR_DOC_KWARGS as _QUANTILE_STD_AND_VAR_DOC_KWARGS,
    SCOPE_DOC as _SCOPE_DOC,
    VariableColumnConvertibleOrLevel,
)
from ._vector import vector


@overload
def quantile(
    operand: VariableColumnConvertibleOrLevel,
    /,
    q: _Q | VariableMeasureConvertible,
    *,
    mode: _Mode = ...,
    interpolation: _Interpolation = ...,
) -> MeasureDescription: ...


@overload
def quantile(
    operand: VariableMeasureConvertible,
    /,
    q: _Q | VariableMeasureConvertible,
    *,
    mode: _Mode = ...,
    interpolation: _Interpolation = ...,
    scope: Scope,
) -> MeasureDescription: ...


@doc(_QUANTILE_DOC, _SCOPE_DOC, **_QUANTILE_STD_AND_VAR_DOC_KWARGS)
def quantile(
    operand: VariableColumnConvertibleOrLevel | VariableMeasureConvertible,
    /,
    q: _Q | VariableMeasureConvertible,
    *,
    mode: _Mode = "inc",
    interpolation: _Interpolation = "linear",
    scope: Scope | None = None,
) -> MeasureDescription:
    return array_quantile(
        # The type checkers cannot see that the `@overload` above ensure that this call is valid.
        vector(operand, scope=scope),  # type: ignore[arg-type] # pyright: ignore[reportArgumentType]
        q=q,
        mode=mode,
        interpolation=interpolation,
    )

==> atoti_client-0.9.5-py3-none-any.whl: atoti/agg/quantile.py <==
from __future__ import annotations

from typing import overload

from .._doc import doc
from .._docs_utils import QUANTILE_DOC as _QUANTILE_DOC
from .._measure_convertible import VariableMeasureConvertible
from .._measure_description import MeasureDescription
from ..array import quantile as array_quantile
from ..array.quantile import _Interpolation, _Mode, _Quantile
from ..scope._scope import Scope
from ._utils import (
    QUANTILE_STD_AND_VAR_DOC_KWARGS as _QUANTILE_STD_AND_VAR_DOC_KWARGS,
    SCOPE_DOC as _SCOPE_DOC,
    LevelOrVariableColumnConvertible,
)
from ._vector import vector


@overload
def quantile(
    operand: LevelOrVariableColumnConvertible,
    /,
    q: _Quantile,
    *,
    mode: _Mode = ...,
    interpolation: _Interpolation = ...,
) -> MeasureDescription: ...


@overload
def quantile(
    operand: VariableMeasureConvertible,
    /,
    q: _Quantile,
    *,
    mode: _Mode = ...,
    interpolation: _Interpolation = ...,
    scope: Scope,
) -> MeasureDescription: ...


@doc(_QUANTILE_DOC, _SCOPE_DOC, **_QUANTILE_STD_AND_VAR_DOC_KWARGS)
def quantile(
    operand: LevelOrVariableColumnConvertible | VariableMeasureConvertible,
    /,
    q: _Quantile,
    *,
    mode: _Mode = "inc",
    interpolation: _Interpolation = "linear",
    scope: Scope | None = None,
) -> MeasureDescription:
    return array_quantile(
        # The type checkers cannot see that the `@overload` above ensure that this call is valid.
        vector(operand, scope=scope),  # type: ignore[arg-type] # pyright: ignore[reportArgumentType]
        q=q,
        mode=mode,
        interpolation=interpolation,
    )
